==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/quicksight/kotlin/inputs/AnalysisParametersDecimalParameterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.quicksight.kotlin.inputs

import com.pulumi.aws.quicksight.inputs.AnalysisParametersDecimalParameterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Double
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property name Display name for the analysis.
 * The following arguments are optional:
 * @property values
 */
public data class AnalysisParametersDecimalParameterArgs(
    public val name: Output<String>,
    public val values: Output<List<Double>>,
) : ConvertibleToJava<com.pulumi.aws.quicksight.inputs.AnalysisParametersDecimalParameterArgs> {
    override fun toJava(): com.pulumi.aws.quicksight.inputs.AnalysisParametersDecimalParameterArgs =
        com.pulumi.aws.quicksight.inputs.AnalysisParametersDecimalParameterArgs.builder()
            .name(name.applyValue({ args0 -> args0 }))
            .values(values.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [AnalysisParametersDecimalParameterArgs].
 */
@PulumiTagMarker
public class AnalysisParametersDecimalParameterArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var values: Output<List<Double>>? = null

    /**
     * @param value Display name for the analysis.
     * The following arguments are optional:
     */
    @JvmName("crbrrbmsvyddbhqy")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value
     */
    @JvmName("krlfvmwslrtylpfe")
    public suspend fun values(`value`: Output<List<Double>>) {
        this.values = value
    }

    @JvmName("niyticqofgbinble")
    public suspend fun values(vararg values: Output<Double>) {
        this.values = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("ilerbbxarwuyiyin")
    public suspend fun values(values: List<Output<Double>>) {
        this.values = Output.all(values)
    }

    /**
     * @param value Display name for the analysis.
     * The following arguments are optional:
     */
    @JvmName("xlekhfugfpcdqrie")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value
     */
    @JvmName("ooykcfgysdxagwsn")
    public suspend fun values(`value`: List<Double>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.values = mapped
    }

    /**
     * @param values
     */
    @JvmName("jobrhdhgjamhmyxx")
    public suspend fun values(vararg values: Double) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.values = mapped
    }

    internal fun build(): AnalysisParametersDecimalParameterArgs =
        AnalysisParametersDecimalParameterArgs(
            name = name ?: throw PulumiNullFieldException("name"),
            values = values ?: throw PulumiNullFieldException("values"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/quicksight/kotlin/inputs/AnalysisParametersDecimalParameterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.quicksight.kotlin.inputs

import com.pulumi.aws.quicksight.inputs.AnalysisParametersDecimalParameterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Double
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property name Display name for the analysis.
 * The following arguments are optional:
 * @property values
 */
public data class AnalysisParametersDecimalParameterArgs(
    public val name: Output<String>,
    public val values: Output<List<Double>>,
) : ConvertibleToJava<com.pulumi.aws.quicksight.inputs.AnalysisParametersDecimalParameterArgs> {
    override fun toJava(): com.pulumi.aws.quicksight.inputs.AnalysisParametersDecimalParameterArgs =
        com.pulumi.aws.quicksight.inputs.AnalysisParametersDecimalParameterArgs.builder()
            .name(name.applyValue({ args0 -> args0 }))
            .values(values.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [AnalysisParametersDecimalParameterArgs].
 */
@PulumiTagMarker
public class AnalysisParametersDecimalParameterArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var values: Output<List<Double>>? = null

    /**
     * @param value Display name for the analysis.
     * The following arguments are optional:
     */
    @JvmName("ejqjapwvwfnsgufr")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value
     */
    @JvmName("tiltujfjjswqeiui")
    public suspend fun values(`value`: Output<List<Double>>) {
        this.values = value
    }

    @JvmName("rtotyvafvbvqrtwo")
    public suspend fun values(vararg values: Output<Double>) {
        this.values = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("mxlsydppmfkcmbcx")
    public suspend fun values(values: List<Output<Double>>) {
        this.values = Output.all(values)
    }

    /**
     * @param value Display name for the analysis.
     * The following arguments are optional:
     */
    @JvmName("sdjbswoyqkfnqnia")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value
     */
    @JvmName("mrbxdwtikpgocdci")
    public suspend fun values(`value`: List<Double>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.values = mapped
    }

    /**
     * @param values
     */
    @JvmName("mjgyydhdthntdswm")
    public suspend fun values(vararg values: Double) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.values = mapped
    }

    internal fun build(): AnalysisParametersDecimalParameterArgs =
        AnalysisParametersDecimalParameterArgs(
            name = name ?: throw PulumiNullFieldException("name"),
            values = values ?: throw PulumiNullFieldException("values"),
        )
}
